@@ -79,6 +79,7 @@ def post_json_with_header(url, payload, headers):
         Returns: json string"""
 
     try:
+        pprint(url)
         pprint(headers)
         res = requests.post(url, data=payload, headers=headers)
         pprint(res)
@@ -990,7 +991,7 @@ def log_deploy_application(dhurl, cookies, deploydata):
     return data
 
 def run_circleci_pipeline(pipeline):
-    headers = {"Circle-Token": os.getenv('CI_TOKEN', ''), "Accept": "application/json"}
+    headers = {"Circle-Token": "2b88069948ec829dad359753d48de0b801f2d933", "Accept": "application/json"}
     url = "https://circleci.com/api/v2/project/" + pipeline + "/pipeline"
     data = post_json_with_header(url, '', headers) 
     return data
